@@ -2,7 +2,7 @@
    See the top of datum.h for information on this code.
    N7TAP
 
-   Portions Copyright (C) 2000-2018 The Xastir Group
+   Portions Copyright (C) 2000-2019 The Xastir Group
 
 */
 
@@ -331,8 +331,7 @@ static const double PI = 3.14159265358979323846;
 
 
 /* As you can see this little function is just a 2 step datum shift, going through WGS84. */
-void datum_shift(double *latitude, double *longitude, short fromDatumID, short toDatumID)
-{
+void datum_shift(double *latitude, double *longitude, short fromDatumID, short toDatumID) {
     wgs84_datum_shift(TO_WGS_84,   latitude, longitude, fromDatumID);
     wgs84_datum_shift(FROM_WGS_84, latitude, longitude, toDatumID);
 }
@@ -342,13 +341,12 @@ void datum_shift(double *latitude, double *longitude, short fromDatumID, short t
 
 
 /*
-        Function to convert latitude and longitude in decimal degrees from WGS84 to
-        another datum or from another datum to WGS84. The arguments to this function
-        include a direction flag 'fromWGS84', pointers to double precision latitude
-        and longitude, and an index to the gDatum[] array.
+  Function to convert latitude and longitude in decimal degrees from WGS84 to
+  another datum or from another datum to WGS84. The arguments to this function
+  include a direction flag 'fromWGS84', pointers to double precision latitude
+  and longitude, and an index to the gDatum[] array.
 */
-void wgs84_datum_shift(short fromWGS84, double *latitude, double *longitude, short datumID)
-{
+void wgs84_datum_shift(short fromWGS84, double *latitude, double *longitude, short datumID) {
     double dx = gDatum[datumID].dx;
     double dy = gDatum[datumID].dy;
     double dz = gDatum[datumID].dz;
@@ -356,7 +354,10 @@ void wgs84_datum_shift(short fromWGS84, double *latitude, double *longitude, sho
     double phi = *latitude * PI / 180.0;
     double lambda = *longitude * PI / 180.0;
     double a0, b0, es0, f0;                     /* Reference ellipsoid of input data */
-    double a1, b1, es1, f1;                     /* Reference ellipsoid of output data */
+    // a1 and b1 are never actually used, so don't declare them and set
+    // them (gcc warns about set-but-unused vars)
+    //double a1, b1, es1, f1;                     /* Reference ellipsoid of output data */
+    double es1, f1;                     /* Reference ellipsoid of output data */
     double psi;                                 /* geocentric latitude */
     double x, y, z;                             /* 3D coordinates with respect to original datum */
     double psi1;                                /* transformed geocentric latitude */
@@ -367,13 +368,15 @@ void wgs84_datum_shift(short fromWGS84, double *latitude, double *longitude, sho
     if (fromWGS84) {                            /* convert from WGS84 to new datum */
         a0 = gEllipsoid[E_WGS_84].a;                            /* WGS84 semimajor axis */
         f0 = 1.0 / gEllipsoid[E_WGS_84].invf;                   /* WGS84 flattening */
-        a1 = gEllipsoid[gDatum[datumID].ellipsoid].a;
+        // a1 is never used except to set b1, which itself is never used
+        // a1 = gEllipsoid[gDatum[datumID].ellipsoid].a;
         f1 = 1.0 / gEllipsoid[gDatum[datumID].ellipsoid].invf;
     }
     else {                                      /* convert from datum to WGS84 */
         a0 = gEllipsoid[gDatum[datumID].ellipsoid].a;           /* semimajor axis */
         f0 = 1.0 / gEllipsoid[gDatum[datumID].ellipsoid].invf;  /* flattening */
-        a1 = gEllipsoid[E_WGS_84].a;                            /* WGS84 semimajor axis */
+        // a1 is never used except to set b1, which is never used.
+        // a1 = gEllipsoid[E_WGS_84].a;                            /* WGS84 semimajor axis */
         f1 = 1.0 / gEllipsoid[E_WGS_84].invf;                   /* WGS84 flattening */
         dx = -dx;
         dy = -dy;
@@ -383,7 +386,8 @@ void wgs84_datum_shift(short fromWGS84, double *latitude, double *longitude, sho
     b0 = a0 * (1 - f0);                         /* semiminor axis for input datum */
     es0 = 2 * f0 - f0*f0;                       /* eccentricity^2 */
 
-    b1 = a1 * (1 - f1);                         /* semiminor axis for output datum */
+    // b1 is never used
+    // b1 = a1 * (1 - f1);                         /* semiminor axis for output datum */
     es1 = 2 * f1 - f1*f1;                       /* eccentricity^2 */
 
     /* Convert geodedic latitude to geocentric latitude, psi */
@@ -453,8 +457,7 @@ void wgs84_datum_shift(short fromWGS84, double *latitude, double *longitude, sho
 //
 // Convert lat/long to UTM/UPS coordinates
 void ll_to_utm_ups(short ellipsoidID, const double lat, const double lon,
-        double *utmNorthing, double *utmEasting, char* utmZone, int utmZoneLength)
-{
+                   double *utmNorthing, double *utmEasting, char* utmZone, int utmZoneLength) {
     //converts lat/long to UTM coords.  Equations from USGS Bulletin 1532
     //East Longitudes are positive, West longitudes are negative.
     //North latitudes are positive, South latitudes are negative
@@ -481,7 +484,7 @@ void ll_to_utm_ups(short ellipsoidID, const double lat, const double lon,
     ZoneNumber = (int)((LongTemp + 180)/6) + 1;
 
     if (coordinate_system == USE_UTM_SPECIAL
-            || coordinate_system == USE_MGRS) {
+        || coordinate_system == USE_MGRS) {
 
         // Special zone for southern Norway.  Used for military
         // version of UTM (MGRS) only.
@@ -509,17 +512,17 @@ void ll_to_utm_ups(short ellipsoidID, const double lat, const double lon,
         // We're in the UPS areas (near the poles).  ZoneNumber
         // should not be printed in this case.
         xastir_snprintf(utmZone,
-            utmZoneLength,
-            "%c",
-            utm_letter_designator(lat, lon));
+                        utmZoneLength,
+                        "%c",
+                        utm_letter_designator(lat, lon));
     }
     else {  // We're in the UTM areas (not near the poles).
         //compute the UTM Zone from the latitude and longitude
         xastir_snprintf(utmZone,
-            utmZoneLength,
-            "%d%c",
-            ZoneNumber,
-            utm_letter_designator(lat, lon));
+                        utmZoneLength,
+                        "%d%c",
+                        ZoneNumber,
+                        utm_letter_designator(lat, lon));
     }
 
     eccPrimeSquared = (eccSquared)/(1-eccSquared);
@@ -560,22 +563,22 @@ void ll_to_utm_ups(short ellipsoidID, const double lat, const double lon,
         A = cos(LatRad)*(LongRad-LongOriginRad);
 
         M = a*((1 -
-            eccSquared/4 -
-            3*eccSquared*eccSquared/64 -
-            5*eccSquared*eccSquared*eccSquared/256) * LatRad -
-            (3*eccSquared/8 +
-            3*eccSquared*eccSquared/32 +
-            45*eccSquared*eccSquared*eccSquared/1024) * sin(2*LatRad) +
-            (15*eccSquared*eccSquared/256 + 45*eccSquared*eccSquared*eccSquared/1024) * sin(4*LatRad) -
-            (35*eccSquared*eccSquared*eccSquared/3072) * sin(6*LatRad));
+                eccSquared/4 -
+                3*eccSquared*eccSquared/64 -
+                5*eccSquared*eccSquared*eccSquared/256) * LatRad -
+               (3*eccSquared/8 +
+                3*eccSquared*eccSquared/32 +
+                45*eccSquared*eccSquared*eccSquared/1024) * sin(2*LatRad) +
+               (15*eccSquared*eccSquared/256 + 45*eccSquared*eccSquared*eccSquared/1024) * sin(4*LatRad) -
+               (35*eccSquared*eccSquared*eccSquared/3072) * sin(6*LatRad));
 
         *utmEasting = (double)(k0*N*(A+(1-T+C)*A*A*A/6
-            + (5-18*T+T*T+72*C-58*eccPrimeSquared)*A*A*A*A*A/120)
-            + 500000.0);
+                                     + (5-18*T+T*T+72*C-58*eccPrimeSquared)*A*A*A*A*A/120)
+                               + 500000.0);
 
         *utmNorthing = (double)(k0*(M+N*tan(LatRad)*
-            (A*A/2+(5-T+9*C+4*C*C)*A*A*A*A/24
-            + (61-58*T+T*T+600*C-330*eccPrimeSquared)*A*A*A*A*A*A/720)));
+                                    (A*A/2+(5-T+9*C+4*C*C)*A*A*A*A/24
+                                     + (61-58*T+T*T+600*C-330*eccPrimeSquared)*A*A*A*A*A*A/720)));
 
         if (lat < 0)
             *utmNorthing += 10000000.0; //10000000 meter offset for southern hemisphere
@@ -588,8 +591,7 @@ void ll_to_utm_ups(short ellipsoidID, const double lat, const double lon,
 
 // Handles UPS/UTM coordinates equally well!
 //
-char utm_letter_designator(double lat, double lon)
-{
+char utm_letter_designator(double lat, double lon) {
     // This routine determines the correct UTM/UPS letter designator
     // for the given latitude.  Originally written by Chuck Gantz-
     // chuck.gantz@globalstar.com
@@ -644,15 +646,14 @@ char utm_letter_designator(double lat, double lon)
 // derived from code that John Waers <jfwaers@csn.net> placed in
 // the public domain.  It's from his program "MacGPS45".
 // 
-static void calcPhi(double *phi, double e, double t)
-{
-        double old = PI/2.0 - 2.0 * atan(t);
-        short maxIterations = 20;
+static void calcPhi(double *phi, double e, double t) {
+    double old = PI/2.0 - 2.0 * atan(t);
+    short maxIterations = 20;
         
-        while ( (fabs((*phi - old) / *phi) > 1.0e-8) && maxIterations-- ) { 
-                old = *phi;
-                *phi = PI/ 2.0 - 2.0 * atan( t * pow((1.0 - e * sin(*phi)) / ((1.0 + e * sin(*phi))), (e / 2.0)) );
-        }
+    while ( (fabs((*phi - old) / *phi) > 1.0e-8) && maxIterations-- ) {
+        old = *phi;
+        *phi = PI/ 2.0 - 2.0 * atan( t * pow((1.0 - e * sin(*phi)) / ((1.0 + e * sin(*phi))), (e / 2.0)) );
+    }
 }
 
 
@@ -662,8 +663,7 @@ static void calcPhi(double *phi, double e, double t)
 // Converts from UTM/UPS coordinates to Lat/Long coordinates.
 //
 void utm_ups_to_ll(short ellipsoidID, const double utmNorthing, const double utmEasting,
-               const char* utmZone, double *lat,  double *lon)
-{
+                   const char* utmZone, double *lat,  double *lon) {
     // Converts UTM coords to lat/long.  Equations from USGS
     // Bulletin 1532.  East Longitudes are positive, West longitudes
     // are negative.  North latitudes are positive, South latitudes
@@ -679,17 +679,20 @@ void utm_ups_to_ll(short ellipsoidID, const double utmNorthing, const double utm
     double e1 = (1-sqrt(1-eccSquared))/(1+sqrt(1-eccSquared));
     double N1, T1, C1, R1, D, M;
     double LongOrigin;
-    double mu, phi1, phi1Rad;
+    // phi1 is never used, but is set.  Don't make gcc warn us
+    // double mu, phi1, phi1Rad;
+    double mu, phi1Rad;
     double x, y;
     int ZoneNumber;
     char* ZoneLetter;
-    int NorthernHemisphere; // 1=northern hemisphere, 0=southern
+    // Unused variable
+    // int NorthernHemisphere; // 1=northern hemisphere, 0=southern
 
 
-//fprintf(stderr,"%s  %f  %f\n",
-//    utmZone,
-//    utmEasting,
-//    utmNorthing);
+    //fprintf(stderr,"%s  %f  %f\n",
+    //    utmZone,
+    //    utmEasting,
+    //    utmNorthing);
 
     x = utmEasting;
     y = utmNorthing;
@@ -702,12 +705,12 @@ void utm_ups_to_ll(short ellipsoidID, const double utmNorthing, const double utm
     // Make sure the zone letter is upper-case
     *ZoneLetter = toupper(*ZoneLetter);
 
-//fprintf(stderr,"ZoneLetter: %s\n", ZoneLetter);
+    //fprintf(stderr,"ZoneLetter: %s\n", ZoneLetter);
 
     if (       *ZoneLetter == 'Y'       // North Pole
-            || *ZoneLetter == 'Z'       // North Pole
-            || *ZoneLetter == 'A'       // South Pole
-            || *ZoneLetter == 'B') {    // South Pole
+               || *ZoneLetter == 'Z'       // North Pole
+               || *ZoneLetter == 'A'       // South Pole
+               || *ZoneLetter == 'B') {    // South Pole
 
         // The following piece of code which implements UPS
         // conversion is derived from code that John Waers
@@ -723,7 +726,7 @@ void utm_ups_to_ll(short ellipsoidID, const double utmNorthing, const double utm
         const double k0 = 0.994;
 
 
-//fprintf(stderr,"UPS Coordinates\n");
+        //fprintf(stderr,"UPS Coordinates\n");
 
 
         e = sqrt(eccSquared);
@@ -780,10 +783,13 @@ void utm_ups_to_ll(short ellipsoidID, const double utmNorthing, const double utm
     y = utmNorthing;
  
 
-    if ((*ZoneLetter - 'N') >= 0)
-        NorthernHemisphere = 1;//point is in northern hemisphere
+    if ((*ZoneLetter - 'N') >= 0) {
+        // We never use this variable
+        // NorthernHemisphere = 1;//point is in northern hemisphere
+    }
     else {
-        NorthernHemisphere = 0;//point is in southern hemisphere
+        // we never use NorthernHemisphere
+        // NorthernHemisphere = 0;//point is in southern hemisphere
         y -= 10000000.0;//remove 10,000,000 meter offset used for southern hemisphere
     }
 
@@ -795,9 +801,10 @@ void utm_ups_to_ll(short ellipsoidID, const double utmNorthing, const double utm
     mu = M/(a*(1-eccSquared/4-3*eccSquared*eccSquared/64-5*eccSquared*eccSquared*eccSquared/256));
 
     phi1Rad = mu + (3*e1/2-27*e1*e1*e1/32)*sin(2*mu)
-                 + (21*e1*e1/16-55*e1*e1*e1*e1/32)*sin(4*mu)
-                 + (151*e1*e1*e1/96)*sin(6*mu);
-    phi1 = phi1Rad*rad2deg;
+        + (21*e1*e1/16-55*e1*e1*e1*e1/32)*sin(4*mu)
+        + (151*e1*e1*e1/96)*sin(6*mu);
+    // This variable is never used, it is just phi1Rad converted to degrees
+    //    phi1 = phi1Rad*rad2deg;
 
     N1 = a/sqrt(1-eccSquared*sin(phi1Rad)*sin(phi1Rad));
     T1 = tan(phi1Rad)*tan(phi1Rad);
