@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,8 +75,8 @@ char *call_only(char *callsign) {
 
 
 /* ====================================================================  */
-/*    build a new (or newer if I check the file date) index file	 */
-/*    check for current ic index file					 */
+/*    build a new (or newer if I check the file date) index file     */
+/*    check for current ic index file                     */
 /*    FG: added a date check in case the FCC file has been updated.    */
 /*      appl.dat must have a time stamp newer than the index file time  */
 /*      stamp. Use the touch command on the appl.dat file to make the   */
@@ -143,7 +143,12 @@ int build_fcc_index(int type){
     xastir_snprintf(fccdata,sizeof(fccdata)," ");
     while(!feof(fdb)) {
         call_offset = (unsigned long)ftell(fdb);
-        (void)fgets(fccdata, (int)sizeof(fccdata), fdb);
+        if (fgets(fccdata, (int)sizeof(fccdata), fdb) == NULL) {
+            // error occurred
+            fprintf(stderr,"Build: Could not read fcc data base: %s \n", appl_file_path);
+            (void)fclose(fdb);
+            return(0);
+        }
         found=0;
         num=0;
         if (type==2) {
@@ -292,7 +297,12 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
     get_user_base_dir("data/appl.ndx", appl_file_path, sizeof(appl_file_path));
     fndx=fopen(appl_file_path,"r");
     if (fndx!=NULL){
-        (void)fgets(index,(int)sizeof(index),fndx);
+        if (fgets(index,(int)sizeof(index),fndx) == NULL) {
+            // Error occurred
+            fprintf(stderr,"Search:Could not read FCC database index(1): %s\n",appl_file_path);
+            return(0);
+        }
+
         xastir_snprintf(char_offset,sizeof(char_offset),"%s",&index[6]);
 
         // Search through the indexes looking for a callsign which is
@@ -300,7 +310,11 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
         // the alphabet than the current index, snag the next index.
         while (!feof(fndx) && strncmp(callsign,index,6) > 0) {
             xastir_snprintf(char_offset,sizeof(char_offset),"%s",&index[6]);
-            (void)fgets(index,(int)sizeof(index),fndx);
+            if (fgets(index,(int)sizeof(index),fndx) == NULL) {
+                // Error occurred
+                fprintf(stderr,"Search:Could not read FCC database index(2): %s\n", appl_file_path );
+                return(0);
+            }
         }
     } else {
         fprintf(stderr,"Search:Could not open FCC data base index: %s\n", appl_file_path );
