@@ -1,7 +1,7 @@
-/* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
+/*
  *
  *
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This file was contributed by Jerry Dunmire, KA6HLD.
  *
@@ -23,7 +23,7 @@
  *
  * This file derived from map_tiger.c which has the following copyrights:
  *    Copyright (C) 1999,2000  Frank Giannandrea
- *    Copyright (C) 2000-2018 The Xastir Group
+ *    Copyright (C) 2000-2019 The Xastir Group
  */
 
 
@@ -77,6 +77,7 @@
 #include "map_cache.h"
 
 #include "tile_mgmnt.h"
+#include "dlm.h"
 #include "map_OSM.h"
 
 #define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
@@ -194,7 +195,7 @@ static long osm_scale_x(long xastir_scale_x) {
        if (xastir_scale_x > osm_level[i]) {
             continue;
         } else {
-            if (abs(osm_level[i - 1] - xastir_scale_x) < abs(osm_level[i] - xastir_scale_x)) {
+            if (labs(osm_level[i - 1] - xastir_scale_x) < labs(osm_level[i] - xastir_scale_x)) {
                 osm_scale_x = osm_level[i - 1];
             } else {
                 osm_scale_x = osm_level[i];
@@ -288,8 +289,8 @@ void set_OSM_report_scale_key(KeySym key) {
     return;
 }
 
-static void get_OSM_local_file(char * local_filename, char * fileimg){
 #ifdef HAVE_MAGICK
+static void get_OSM_local_file(char * local_filename, char * fileimg){
     time_t query_start_time, query_end_time; 
 
 #ifdef USE_MAP_CACHE 
@@ -317,9 +318,9 @@ static void get_OSM_local_file(char * local_filename, char * fileimg){
             }
         }
 
-set_dangerous("map_OSM: map_cache_get");
-	map_cache_return = map_cache_get(fileimg,local_filename); 
-clear_dangerous();
+        set_dangerous("map_OSM: map_cache_get");
+        map_cache_return = map_cache_get(fileimg,local_filename); 
+        clear_dangerous();
     }
 
     if (debug_level & 512) {
@@ -330,7 +331,7 @@ clear_dangerous();
    
     if (map_cache_return != 0 ) {
 
-set_dangerous("map_OSM: map_cache_fileid");
+        set_dangerous("map_OSM: map_cache_fileid");
         cache_file_id = map_cache_fileid();
         xastir_snprintf(local_filename,
             MAX_FILENAME,           // hardcoded to avoid sizeof()
@@ -369,9 +370,9 @@ clear_dangerous();
  
 #ifdef USE_MAP_CACHE
 
-set_dangerous("map_OSM: map_cache_put");
-	map_cache_put(fileimg,local_filename); 
-clear_dangerous();
+    set_dangerous("map_OSM: map_cache_put");
+    map_cache_put(fileimg,local_filename); 
+    clear_dangerous();
 
         } // end if is cached  DHBROWN
 
@@ -386,11 +387,12 @@ clear_dangerous();
     // Set permissions on the file so that any user can overwrite it.
     chmod(local_filename, 0666);
 
+} // end get_OSM_local_file
 #endif  //HAVE_MAGICK
 
-} // end get_OSM_local_file
 
 
+#ifdef HAVE_MAGICK
 static long xastirLat2pixelLat(
         long xlat, int osm_zoom ) {
     double lat;  // in radians
@@ -416,8 +418,10 @@ static long xastirLat2pixelLat(
     pixelLat = (long)((y * (double)(1<<(osm_zoom + 8))) / 2.0);
     return(pixelLat);
 } // xastirLat2pixelLat()
+#endif  // HAVE_MAGICK
   
 
+#ifdef HAVE_MAGICK
 static double pixelLat2Lat(long osm_lat, int osm_zoom){
     double lat, projection, y;
     y = (double)osm_lat * 2.0 / (double)(1<<(osm_zoom + 8));
@@ -427,8 +431,10 @@ static double pixelLat2Lat(long osm_lat, int osm_zoom){
     lat = (lat * 180.0 ) / M_PI;
     return(lat);
 } // pixelLat2Lat()
+#endif  // HAVE_MAGICK
 
 
+#ifdef HAVE_MAGICK
 static long pixelLat2xastirLat(long osm_lat, int osm_zoom) {
     double lat;
     long xastirLat;
@@ -436,8 +442,10 @@ static long pixelLat2xastirLat(long osm_lat, int osm_zoom) {
     xastirLat = (long)((90.0 - lat) * 3600.0 * 100.0);
     return (xastirLat);
 } // pixelLat2xastirLat()
+#endif  // HAVE_MAGICK
 
 
+#ifdef HAVE_MAGICK
 static long xastirLon2pixelLon(
         long xlon, int osm_zoom) {
     double lon;
@@ -448,24 +456,30 @@ static long xastirLon2pixelLon(
     pixelLon = lon;
     return(pixelLon);
 } // xastirLon2pixelLon()
+#endif  // HAVE_MAGICK
 
 
+#ifdef HAVE_MAGICK
 static double pixelLon2Lon(long osm_lon, int osm_zoom) {
     double lon;
     lon = osm_lon * 360.0 ;
     lon = lon / (1<<(osm_zoom + 8));
     return(lon);
 } // pixelLon2Lon()
+#endif  // HAVE_MAGICK
 
 
+#ifdef HAVE_MAGICK
 static long pixelLon2xastirLon(long osm_lon, int osm_zoom) {
     long xastirLon;
     xastirLon = (long)(pixelLon2Lon(osm_lon, osm_zoom) * 3600.0 * 100.0);
     return(xastirLon);
 } // pixelLon2xastirLon()
+#endif  // HAVE_MAGICK
 
 
 #ifdef HAVE_MAGICK
+
 /**********************************************************
  * draw_image() - copy a image onto the display
  **********************************************************/
@@ -489,8 +503,9 @@ static void draw_image(
 
 /*
     if (image->colorspace != RGBColorspace) {
-        fprintf(stderr,"TBD: I don't think we can deal with colorspace != RGB");
-        return;
+        TransformImageColorspace(image, RGBColorspace);
+        //fprintf(stderr,"TBD: I don't think we can deal with colorspace != RGB");
+        //return;
     }
 */
 
@@ -516,13 +531,29 @@ static void draw_image(
     }
 
 
+#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
     pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
+#else
+    pixel_pack = GetAuthenticPixels(image, 0, 0, image->columns, image->rows, except_ptr);
+#endif
     if (!pixel_pack) {
         fprintf(stderr,"pixel_pack == NULL!!!");
         return;
     }
 
+#if defined(HAVE_GRAPHICSMAGICK)
+  #if (MagickLibVersion < 0x201702)
     index_pack = GetIndexes(image);
+  #else
+    index_pack = AccessMutableIndexes(image);
+  #endif
+#else
+  #if (MagickLibVersion < 0x0669)
+    index_pack = GetIndexes(image);
+  #else
+    index_pack = GetAuthenticIndexQueue(image);
+  #endif
+#endif
     if (image->storage_class == PseudoClass && !index_pack) {
         fprintf(stderr,"PseudoClass && index_pack == NULL!!!");
         return;
@@ -555,9 +586,9 @@ static void draw_image(
             else {  // QuantumDepth = 8
                 if (debug_level & 512)
                     fprintf(stderr,"Color quantum is [0..255]\n");
-                my_colors[l].red   = (temp_pack.red << 8) * raster_map_intensity;
-                my_colors[l].green = (temp_pack.green << 8) * raster_map_intensity;
-                my_colors[l].blue  = (temp_pack.blue << 8) * raster_map_intensity;
+                my_colors[l].red   = (temp_pack.red * 256) * raster_map_intensity;
+                my_colors[l].green = (temp_pack.green * 256) * raster_map_intensity;
+                my_colors[l].blue  = (temp_pack.blue * 256) * raster_map_intensity;
             }
 
             // Get the color allocated on < 8bpp displays. pixel color is written to my_colors.pixel
@@ -607,7 +638,7 @@ static void draw_image(
                 if (xastirColorsMatch(pixel_pack[l],image->matte_color)) {
                     continue;
                 }
-                XSetForeground(XtDisplay(w), gc, my_colors[index_pack[l]].pixel);
+                XSetForeground(XtDisplay(w), gc, my_colors[(int)index_pack[l]].pixel);
             }
             else {
                 // Skip transparent pixels
@@ -626,9 +657,9 @@ static void draw_image(
                 else { // QuantumDepth=8
                     // shift the bits of the 8-bit quantity so that
                     // they become the high bigs of my_colors.*
-                    my_colors[0].red=pixel_pack[l].red<<8;
-                    my_colors[0].green=pixel_pack[l].green<<8;
-                    my_colors[0].blue=pixel_pack[l].blue<<8;
+                    my_colors[0].red=pixel_pack[l].red*256;
+                    my_colors[0].green=pixel_pack[l].green*256;
+                    my_colors[0].blue=pixel_pack[l].blue*256;
                 }
                 // NOW my_colors has the right r,g,b range for
                 // pack_pixel_bits
@@ -681,8 +712,9 @@ static void draw_OSM_image(
 
 /*
     if (image->colorspace != RGBColorspace) {
-        fprintf(stderr,"TBD: I don't think we can deal with colorspace != RGB");
-        return;
+        TransformImageColorspace(image, RGBColorspace);
+        //fprintf(stderr,"TBD: I don't think we can deal with colorspace != RGB");
+        //return;
     }
 */
 
@@ -708,13 +740,29 @@ static void draw_OSM_image(
     }
 
 
+#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x669)
     pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
+#else
+    pixel_pack = GetAuthenticPixels(image, 0, 0, image->columns, image->rows, except_ptr);
+#endif
     if (!pixel_pack) {
         fprintf(stderr,"pixel_pack == NULL!!!");
         return;
     }
 
+#if defined(HAVE_GRAPHICSMAGICK)
+  #if (MagickLibVersion < 0x201702)
     index_pack = GetIndexes(image);
+  #else
+    index_pack = AccessMutableIndexes(image);
+  #endif
+#else
+  #if (MagickLibVersion < 0x0669)
+    index_pack = GetIndexes(image);
+  #else
+    index_pack = GetAuthenticIndexQueue(image);
+  #endif
+#endif
     if (image->storage_class == PseudoClass && !index_pack) {
         fprintf(stderr,"PseudoClass && index_pack == NULL!!!");
         return;
@@ -747,9 +795,9 @@ static void draw_OSM_image(
             else {  // QuantumDepth = 8
                 //if (debug_level & 512)
                 //    fprintf(stderr,"Color quantum is [0..255]\n");
-                my_colors[l].red   = (temp_pack.red << 8) * raster_map_intensity;
-                my_colors[l].green = (temp_pack.green << 8) * raster_map_intensity;
-                my_colors[l].blue  = (temp_pack.blue << 8) * raster_map_intensity;
+                my_colors[l].red   = (temp_pack.red * 256) * raster_map_intensity;
+                my_colors[l].green = (temp_pack.green * 256) * raster_map_intensity;
+                my_colors[l].blue  = (temp_pack.blue * 256) * raster_map_intensity;
             }
 
             // Get the color allocated on < 8bpp displays. pixel color is written to my_colors.pixel
@@ -885,7 +933,7 @@ static void draw_OSM_image(
                             if (xastirColorsMatch(pixel_pack[l],image->matte_color)) {
                                 continue;
                             }
-                            XSetForeground(XtDisplay(w), gc, my_colors[index_pack[l]].pixel);
+                            XSetForeground(XtDisplay(w), gc, my_colors[(int)index_pack[l]].pixel);
                         }
                         else {
                             // Skip transparent pixels and make matte
@@ -906,9 +954,9 @@ static void draw_OSM_image(
                             else { // QuantumDepth=8
                                 // shift the bits of the 8-bit quantity so that
                                 // they become the high bigs of my_colors.*
-                                my_colors[0].red=pixel_pack[l].red<<8;
-                                my_colors[0].green=pixel_pack[l].green<<8;
-                                my_colors[0].blue=pixel_pack[l].blue<<8;
+                                my_colors[0].red=pixel_pack[l].red*256;
+                                my_colors[0].green=pixel_pack[l].green*256;
+                                my_colors[0].blue=pixel_pack[l].blue*256;
                             }
                             // NOW my_colors has the right r,g,b range for
                             // pack_pixel_bits
@@ -928,6 +976,7 @@ static void draw_OSM_image(
 
             if (map_seen && !map_act)
                 map_done = 1;
+            (void)map_done; // map_done is never used, but this takes away the compile warning.
         } // don't do a screen row twice.
     } // loop over map pixel rows
 }  // end draw_OSM_image()
@@ -970,11 +1019,6 @@ void draw_OSM_tiles (Widget w,
     unsigned int offset_x, offset_y;
     char tmpString[MAX_TMPSTRING];
 
-#ifdef HAVE_LIBCURL
-    CURL *mySession;
-    char errBuf[CURL_ERROR_SIZE];
-    int curl_result;
-#endif // HAVE_LIBCURL
     char temp_file_path[MAX_VALUE];
 
     // Check whether we're indexing or drawing the map
@@ -1089,10 +1133,6 @@ void draw_OSM_tiles (Widget w,
                             tiles.endy, osm_zl, tileRootDir,
                             tileExt[0] != '\0' ? tileExt : "png");
 
-#ifdef HAVE_LIBCURL
-    mySession = xastir_curl_init(errBuf);
-#endif // HAVE_LIBCURL
-
     // get the tiles
     tileCnt = 1;
     for (tilex = tiles.startx; tilex <= tiles.endx; tilex++) {
@@ -1104,37 +1144,17 @@ void draw_OSM_tiles (Widget w,
                 XmUpdateDisplay(text);
             }
 
-#ifdef HAVE_LIBCURL
-            curl_result = getOneTile(mySession, serverURL, tilex, tiley,
+            DLM_queue_tile(serverURL, tilex, tiley,
                     osm_zl, tileRootDir, tileExt[0] != '\0' ? tileExt : "png");
-            if (curl_result < 0) {
-               fprintf(stderr, "Download error for tile: %s/%i/%li/%li.%s\n",
-                       serverURL, osm_zl, tilex, tiley,
-                       tileExt[0] != '\0' ? tileExt : "png");
-               fprintf(stderr, "curl told us %d\n", -1 * curl_result);
-               fprintf(stderr, "curlerr: %s\n", errBuf);
-            } else {
-                tileCnt += curl_result;
-            }
-#else
-            tileCnt += getOneTile(serverURL, tilex, tiley,
-                    osm_zl, tileRootDir, tileExt[0] != '\0' ? tileExt : "png");
-#endif // HAVE_LIBCURL
 
-            HandlePendingEvents(app_context);
-            if (interrupt_drawing_now) {
-                interrupted = 1;
-                break;
-            }
-        }
-        if (interrupted == 1) {
-            break;
         }
     }
 
-#ifdef HAVE_LIBCURL
-    curl_easy_cleanup(mySession);
-#endif // HAVE_LIBCURL
+    // if the Download Manager is not using threaded (background) mode,
+    // we need this to actually do the downloads.
+    // In threaded mode, it does nothing
+    DLM_do_transfers();
+    if (interrupt_drawing_now) interrupted = 1;
 
     if (interrupted != 1) {
         // calculate tie points
@@ -1191,11 +1211,13 @@ void draw_OSM_tiles (Widget w,
          * transparent when the completed OSM map gets copied to the X
          * display.
          */
-        FormatString(canvas_info->filename, "%s", MATTE_COLOR_STRING);
+        xastir_snprintf(canvas_info->filename, sizeof(canvas_info->filename),
+                 "%s", MATTE_COLOR_STRING);
         canvas = ReadImage(canvas_info, &exception);
         if (exception.severity != UndefinedException) {
             CatchException(&exception);
             fprintf(stderr, "Could not allocate canvas to hold tiles.\n");
+
             if (canvas_info != NULL) {
                 DestroyImageInfo(canvas_info);
             }
@@ -1212,7 +1234,12 @@ void draw_OSM_tiles (Widget w,
         canvas->background_color.green = MATTE_GREEN;
         canvas->background_color.blue = MATTE_BLUE;
         canvas->background_color.opacity = MATTE_OPACITY;
+#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
         SetImage(canvas, MATTE_OPACITY);
+#else
+        SetImageBackgroundColor(canvas);
+        SetImageOpacity(canvas, MATTE_OPACITY);
+#endif
 
         xastir_snprintf(map_it, sizeof(map_it), "%s",
                 langcode ("BBARSTA049")); // Reading tiles...
@@ -1228,22 +1255,32 @@ void draw_OSM_tiles (Widget w,
             for (row = tiles.startx, offset_x = 0;
                  row <= tiles.endx;
                  row++, offset_x += 256) {
+
                 xastir_snprintf(tmpString, sizeof(tmpString),
                         "%s/%d/%d/%d.%s", tileRootDir, osm_zl, row, col,
                         tileExt[0] != '\0' ? tileExt : "png");
                 strncpy(tile_info->filename, tmpString, MaxTextExtent);
 
                 tile = ReadImage(tile_info,&exception);
+
                 if (exception.severity != UndefinedException) {
-                    CatchException(&exception);
-                    xastir_snprintf(tmpString, sizeof(tmpString), "%s/%d/%d/%d.%s",
+                    //fprintf(stderr,"Exception severity:%d\n", exception.severity);
+                    if (exception.severity==FileOpenError) {
+                       //fprintf(stderr, "%s NOT available\n", tile_info->filename);
+#if !defined(HAVE_GRAPHICSMAGICK) && (MagickLibVersion > 0x0669)
+                       ClearMagickException(&exception);
+#endif
+                    } else {
+                       xastir_snprintf(tmpString, sizeof(tmpString), "%s/%d/%d/%d.%s",
                             tileRootDir, osm_zl, row, col,
                             tileExt[0] != '\0' ? tileExt : "png");
-                    if (debug_level & 512) {
-                        fprintf(stderr, "%s NOT removed.\n", tmpString);
-                    } else {
-                        fprintf(stderr, "Removing %s\n", tmpString);
-                        unlink(tmpString);
+                       if (debug_level & 512) {
+                           fprintf(stderr, "%s NOT removed.\n", tmpString);
+                       } else {
+                           fprintf(stderr, "Removing %s\n", tmpString);
+                           unlink(tmpString);
+                       }
+                       CatchException(&exception);
                     }
                     // clear exception so next iteration doesn't fail
                     GetExceptionInfo(&exception);
@@ -1266,7 +1303,11 @@ void draw_OSM_tiles (Widget w,
         canvas->matte_color.blue = MATTE_BLUE;
 
         if (debug_level & 512) {
+#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
             DescribeImage(canvas, stderr, 0);
+#else
+            IdentifyImage(canvas, stderr, 0);
+#endif
             WriteImages(canvas_info, canvas, "/tmp/xastirOSMTiledMap.png", &exception);
         }
 
@@ -1564,7 +1605,7 @@ void draw_OSM_map (Widget w,
          
         if (image_info)
             DestroyImageInfo(image_info);
-	DestroyExceptionInfo(&exception);
+    DestroyExceptionInfo(&exception);
         return;
     }
     (void)fclose (f);
@@ -1587,7 +1628,7 @@ void draw_OSM_map (Widget w,
 
         if (image_info)
             DestroyImageInfo(image_info);
-	DestroyExceptionInfo(&exception);
+    DestroyExceptionInfo(&exception);
         return;
 
     } else if ( (image->columns != map_image_width)
