@@ -1,8 +1,8 @@
-/* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
+/*
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -156,38 +156,38 @@ void draw_WMS_map (Widget w,
     char WMStmp[MAX_FILENAME*2];  // Used for putting together the WMS map query
     int width, height;
     tiepoint tp[2];                 // Calibration points for map, read in from .geo file
-    register long map_c_T, map_c_L; // map delta NW edge coordinates, DNN: these should be signed
-    register long tp_c_dx, tp_c_dy; // tiepoint coordinate differences
+    long map_c_T, map_c_L;          // map delta NW edge coordinates, DNN: these should be signed
+    long tp_c_dx, tp_c_dy;          // tiepoint coordinate differences
     unsigned long c_x_min,  c_y_min;// top left coordinates of map inside screen
-    unsigned long c_y_max;          // bottom right coordinates of map inside screen
+//  unsigned long c_y_max;          // bottom right coordinates of map inside screen
     double c_x;                     // Xastir coordinates 1/100 sec, 0 = 180W
     double c_y;                     // Xastir coordinates 1/100 sec, 0 =  90N
 
     long map_y_0;                   // map pixel pointer prior to TM adjustment
-    register long map_x, map_y;     // map pixel pointers, DNN: this was a float, chg to long
+    long map_x, map_y;              // map pixel pointers, DNN: this was a float, chg to long
     long map_x_min, map_x_max;      // map boundaries for in screen part of map
     long map_y_min, map_y_max;      //
-    long map_x_ctr;                 // half map width in pixel
-    long map_y_ctr;                 // half map height in pixel
+//  long map_x_ctr;                 // half map width in pixel
+//  long map_y_ctr;                 // half map height in pixel
     int map_seen = 0;
     int map_act;
-    int map_done;
+//  int map_done;
 
-    long map_c_yc;                  // map center, vert coordinate
-    long map_c_xc;                  // map center, hor  coordinate
+//  long map_c_yc;                  // map center, vert coordinate
+//  long map_c_xc;                  // map center, hor  coordinate
     double map_c_dx, map_c_dy;      // map coordinates increment (pixel width)
     double c_dx;                    // adjusted map pixel width
 
     long scr_x,  scr_y;             // screen pixel plot positions
     long scr_xp, scr_yp;            // previous screen plot positions
     int  scr_dx, scr_dy;            // increments in screen plot positions
-    long scr_x_mc;                  // map center in screen units
+//  long scr_x_mc;                  // map center in screen units
 
-    long scr_c_xr;
+//  long scr_c_xr;
 
-    long scale_xa;                  // adjusted for topo maps
-    double scale_x_nm;              // nm per Xastir coordinate unit
-    long scale_x0;                  // at widest map area
+//  long scale_xa;                  // adjusted for topo maps
+//  double scale_x_nm;              // nm per Xastir coordinate unit
+//  long scale_x0;                  // at widest map area
 
     char local_filename[MAX_FILENAME];
     ExceptionInfo exception;
@@ -379,90 +379,6 @@ void draw_WMS_map (Widget w,
 //    strncat(WMStmp, "&BGCOLOR=0x000000", sizeof(WMStmp) - 1 - strlen(WMStmp));
 //    strncat(WMStmp, "&CRS=CRS:84", sizeof(WMStmp) - 1 - strlen(WMStmp));
 
-
-
-
-
-/*
-    xastir_snprintf(WMStmp, sizeof(WMStmp), "http://tiger.census.gov/cgi-bin/mapper/map.png?");
-
-    if (tiger_show_grid)
-        strncat(WMStmp, "&on=GRID", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=GRID", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_counties)
-        strncat(WMStmp, "&on=counties", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=counties", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_cities)
-        strncat(WMStmp, "&on=CITIES", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=CITIES", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_places)
-        strncat(WMStmp, "&on=places", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=places", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_majroads)
-        strncat(WMStmp, "&on=majroads", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=majroads", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_streets)
-        strncat(WMStmp, "&on=streets", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    // Don't turn streets off since this will automagically show up as you zoom in.
-
-    if (tiger_show_railroad)
-        strncat(WMStmp, "&on=railroad", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=railroad", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_states)
-        strncat(WMStmp, "&on=states", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=states", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_interstate)
-        strncat(WMStmp, "&on=interstate", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=interstate", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_ushwy)
-        strncat(WMStmp, "&on=ushwy", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=ushwy", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_statehwy)
-        strncat(WMStmp, "&on=statehwy", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=statehwy", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_water)
-        strncat(WMStmp, "&on=water", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=water", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_lakes)
-        strncat(WMStmp, "&on=shorelin", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=shorelin", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    if (tiger_show_misc)
-        strncat(WMStmp, "&on=miscell", sizeof(WMStmp) - 1 - strlen(WMStmp));
-    else
-        strncat(WMStmp, "&off=miscell", sizeof(WMStmp) - 1 - strlen(WMStmp));
-
-    xastir_snprintf(tmpstr, sizeof(tmpstr), "&lat=%f\046lon=%f\046", lat_center, long_center);    
-    strncat (WMStmp, tmpstr, sizeof(WMStmp) - 1 - strlen(WMStmp));
-    xastir_snprintf(tmpstr, sizeof(tmpstr), "wid=%f\046ht=%f\046", map_width, map_height);
-    strncat (WMStmp, tmpstr, sizeof(WMStmp) - 1 - strlen(WMStmp));
-    xastir_snprintf(tmpstr, sizeof(tmpstr), "iwd=%i\046iht=%i", tp[1].img_x + 1, tp[1].img_y + 1);
-    strncat (WMStmp, tmpstr, sizeof(WMStmp) - 1 - strlen(WMStmp)); */
-
-
     xastir_snprintf(fileimg, sizeof(fileimg), "%s", WMStmp);
 
     if (debug_level & 512) {
@@ -503,16 +419,16 @@ void draw_WMS_map (Widget w,
     }
     else {
         // Else look for the file in the cache
-    	map_cache_return = map_cache_get(fileimg,local_filename); 
+        map_cache_return = map_cache_get(fileimg,local_filename); 
     }
 
-	if (debug_level & 512) {
-		fprintf(stderr,"map_cache_return: %d\n", map_cache_return);
-	}
+    if (debug_level & 512) {
+        fprintf(stderr,"map_cache_return: %d\n", map_cache_return);
+    }
  
 
     // Don't use cached version if "nocache" is non-zero
-    //	   
+    //       
     if (nocache || map_cache_return != 0 ) {
         // Caching has not been requested or cached file not found.
         // We must snag the remote file via libcurl or wget.
@@ -636,7 +552,7 @@ void draw_WMS_map (Widget w,
          
         if (image_info)
             DestroyImageInfo(image_info);
-	DestroyExceptionInfo(&exception);
+    DestroyExceptionInfo(&exception);
         return;
     }
     (void)fclose (f);
@@ -659,7 +575,7 @@ void draw_WMS_map (Widget w,
 
         if (image_info)
             DestroyImageInfo(image_info);
-	DestroyExceptionInfo(&exception);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
@@ -721,7 +637,11 @@ void draw_WMS_map (Widget w,
     }
 
 
+#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
     pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
+#else
+    pixel_pack = GetAuthenticPixels(image, 0, 0, image->columns, image->rows, &exception);
+#endif
     if (!pixel_pack) {
         fprintf(stderr,"pixel_pack == NULL!!!");
         if (image)
@@ -733,7 +653,19 @@ void draw_WMS_map (Widget w,
     }
 
 
+#if defined(HAVE_GRAPHICSMAGICK)
+  #if (MagickLibVersion < 0x201702)
     index_pack = GetIndexes(image);
+  #else
+    index_pack = AccessMutableIndexes(image);
+  #endif
+#else
+  #if (MagickLibVersion < 0x0669)
+    index_pack = GetIndexes(image);
+  #else
+    index_pack = GetAuthenticIndexQueue(image);
+  #endif
+#endif
     if (image->storage_class == PseudoClass && !index_pack) {
         fprintf(stderr,"PseudoClass && index_pack == NULL!!!");
         if (image)
@@ -752,7 +684,7 @@ void draw_WMS_map (Widget w,
             temp_pack = image->colormap[l];
             if (debug_level & 512)
                 fprintf(stderr,"Colormap color is %i  %i  %i \n",
-                       temp_pack.red, temp_pack.green, temp_pack.blue);
+                       (int)temp_pack.red, (int)temp_pack.green, (int)temp_pack.blue);
 
             // Here's a tricky bit:  PixelPacket entries are defined as Quantum's.  Quantum
             // is defined in /usr/include/magick/image.h as either an unsigned short or an
@@ -769,9 +701,9 @@ void draw_WMS_map (Widget w,
             else {  // QuantumDepth = 8
                 if (debug_level & 512)
                     fprintf(stderr,"Color quantum is [0..255]\n");
-                my_colors[l].red   = (temp_pack.red << 8) * raster_map_intensity;
-                my_colors[l].green = (temp_pack.green << 8) * raster_map_intensity;
-                my_colors[l].blue  = (temp_pack.blue << 8) * raster_map_intensity;
+                my_colors[l].red   = (temp_pack.red * 256) * raster_map_intensity;
+                my_colors[l].green = (temp_pack.green * 256) * raster_map_intensity;
+                my_colors[l].blue  = (temp_pack.blue * 256) * raster_map_intensity;
             }
 
             // Get the color allocated on < 8bpp displays. pixel color is written to my_colors.pixel
@@ -886,23 +818,23 @@ void draw_WMS_map (Widget w,
     // Get the border values for the X and Y for loops used
     // for the XFillRectangle call later.
 
-    map_c_yc = (tp[0].y_lat + tp[1].y_lat) / 2;     // vert center of map as reference
-    map_y_ctr = (long)(height / 2 +0.499);
-    scale_x0 = get_x_scale(0,map_c_yc,scale_y);     // reference scaling at vert map center
+//  map_c_yc = (tp[0].y_lat + tp[1].y_lat) / 2;     // vert center of map as reference
+//  map_y_ctr = (long)(height / 2 +0.499);
+//  scale_x0 = get_x_scale(0,map_c_yc,scale_y);     // reference scaling at vert map center
 
-    map_c_xc  = (tp[0].x_long + tp[1].x_long) / 2;  // hor center of map as reference
-    map_x_ctr = (long)(width  / 2 +0.499);
-    scr_x_mc  = (map_c_xc - NW_corner_longitude) / scale_x; // screen coordinates of map center
+//  map_c_xc  = (tp[0].x_long + tp[1].x_long) / 2;  // hor center of map as reference
+//  map_x_ctr = (long)(width  / 2 +0.499);
+//  scr_x_mc  = (map_c_xc - NW_corner_longitude) / scale_x; // screen coordinates of map center
 
     // calculate map pixel range in y direction that falls into screen area
-    c_y_max = 0ul;
+//  c_y_max = 0ul;
     map_y_min = map_y_max = 0l;
     for (map_y_0 = 0, c_y = tp[0].y_lat; map_y_0 < (long)height; map_y_0++, c_y += map_c_dy) {
         scr_y = (c_y - NW_corner_latitude) / scale_y;   // current screen position
         if (scr_y > 0) {
             if (scr_y < screen_height) {
                 map_y_max = map_y_0;          // update last map pixel in y
-                c_y_max = (unsigned long)c_y;// bottom map inside screen coordinate
+//              c_y_max = (unsigned long)c_y;// bottom map inside screen coordinate
             } else
                 break;                      // done, reached bottom screen border
         } else {                            // pixel is above screen
@@ -926,11 +858,11 @@ void draw_WMS_map (Widget w,
         c_x_min = (unsigned long)(tp[0].x_long + map_x_min * map_c_dx);   // left map inside screen coordinate
 
     scr_yp = -1;
-    scr_c_xr = SE_corner_longitude;
+//  scr_c_xr = SE_corner_longitude;
     c_dx = map_c_dx;                            // map pixel width
-    scale_xa = scale_x0;                        // the compiler likes it ;-)
+//  scale_xa = scale_x0;                        // the compiler likes it ;-)
 
-    map_done = 0;
+//  map_done = 0;
     map_act  = 0;
     map_seen = 0;
     scr_y = screen_height - 1;
@@ -965,7 +897,7 @@ void draw_WMS_map (Widget w,
             scr_xp = -1;
             // loop over map pixel columns
             map_act = 0;
-            scale_x_nm = calc_dscale_x(0,(long)c_y) / 1852.0;  // nm per Xastir coordinate
+//          scale_x_nm = calc_dscale_x(0,(long)c_y) / 1852.0;  // nm per Xastir coordinate
             for (map_x = map_x_min, c_x = (double)c_x_min; map_x <= map_x_max; map_x++, c_x += c_dx) {
                 scr_x = (c_x - NW_corner_longitude) / scale_x;
                 if (scr_x != scr_xp) {      // don't do a pixel twice
@@ -981,11 +913,11 @@ void draw_WMS_map (Widget w,
                         trans_skip = 1; // possibly transparent
                         if (image->storage_class == PseudoClass) {
                             if ( c_trans_color_head &&
-                                    check_trans(my_colors[index_pack[l]],c_trans_color_head)) {
+                                    check_trans(my_colors[(int)index_pack[l]],c_trans_color_head)) {
                                 trans_skip = 1; // skip it
                             }
                             else {
-                                XSetForeground(XtDisplay(w), gc, my_colors[index_pack[l]].pixel);
+                                XSetForeground(XtDisplay(w), gc, my_colors[(int)index_pack[l]].pixel);
                                 trans_skip = 0; // draw it
                             }
                         }
@@ -1001,9 +933,9 @@ void draw_WMS_map (Widget w,
                             else { // QuantumDepth=8
                                 // shift the bits of the 8-bit quantity so that
                                 // they become the high bigs of my_colors.*
-                                my_colors[0].red=pixel_pack[l].red<<8;
-                                my_colors[0].green=pixel_pack[l].green<<8;
-                                my_colors[0].blue=pixel_pack[l].blue<<8;
+                                my_colors[0].red=pixel_pack[l].red*256;
+                                my_colors[0].green=pixel_pack[l].green*256;
+                                my_colors[0].blue=pixel_pack[l].blue*256;
                             }
                             // NOW my_colors has the right r,g,b range for
                             // pack_pixel_bits
@@ -1029,8 +961,9 @@ void draw_WMS_map (Widget w,
                     } // check map boundaries in y direction
                 }
             } // loop over map pixel columns
-            if (map_seen && !map_act)
-                map_done = 1;
+            if (map_seen && !map_act) {
+//              map_done = 1;
+            }
         }
     } // loop over map pixel rows
 
