@@ -1,8 +1,8 @@
-/* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
+/*
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -81,14 +81,14 @@
 #define DOS_HDR_LINES 8
 #define GRID_MORE 5000
 
-extern int npoints;		/* tsk tsk tsk -- globals */
+extern int npoints;        /* tsk tsk tsk -- globals */
 extern int mag;
 
 /* MAP pointers */
 
-static map_vectors *map_vectors_ptr;
-static text_label *map_text_label_ptr;
-static symbol_label *map_symbol_label_ptr;
+//static map_vectors *map_vectors_ptr;
+//static text_label *map_text_label_ptr;
+//static symbol_label *map_symbol_label_ptr;
 
 /* MAP counters */
 
@@ -369,7 +369,7 @@ void draw_dos_map(Widget w,
     int dos_flag;
     long temp;
     int points_per_degree;
-    int map_range;
+//  int map_range;
   
     /* vector info */
     unsigned char vector_start;
@@ -393,12 +393,12 @@ void draw_dos_map(Widget w,
     long count;
     int label_length;
     int i;
-    int map_maxed_vectors;
-    int map_maxed_text_labels;
-    int map_maxed_symbol_labels;
-    map_vectors *vectors_ptr;
-    text_label *text_ptr;
-    symbol_label *symbol_ptr;
+//  int map_maxed_vectors;
+//  int map_maxed_text_labels;
+//  int map_maxed_symbol_labels;
+//  map_vectors *vectors_ptr;
+//  text_label *text_ptr;
+//  symbol_label *symbol_ptr;
     int line_width;
     int x, y;
     int color;
@@ -422,13 +422,13 @@ void draw_dos_map(Widget w,
     mag = (1 * scale_y) / 2;    // determines if details are drawn
   
     /* MAP counters */
-    vectors_ptr = map_vectors_ptr;
-    text_ptr = map_text_label_ptr;
-    symbol_ptr = map_symbol_label_ptr;
+//  vectors_ptr = map_vectors_ptr;
+//  text_ptr = map_text_label_ptr;
+//  symbol_ptr = map_symbol_label_ptr;
   
-    map_maxed_vectors = 0;
-    map_maxed_text_labels = 0;
-    map_maxed_symbol_labels = 0;
+//  map_maxed_vectors = 0;
+//  map_maxed_text_labels = 0;
+//  map_maxed_symbol_labels = 0;
     npoints = 0;
   
     xastir_snprintf(file, sizeof(file), "%s/%s", dir, filenm);
@@ -458,7 +458,11 @@ void draw_dos_map(Widget w,
         return;
     }
 
-    (void)fread (map_type, 4, 1, f);
+    if (fread (map_type, 4, 1, f) == 0) {
+        // Ignoring fread errors as we've done here since forever.
+        // Would be good to take another look at this later.
+    }
+ 
     map_type[4] = '\0';
     dos_labels = FALSE;
     points_per_degree = 300;
@@ -484,12 +488,16 @@ void draw_dos_map(Widget w,
 
         for (j = 0; j < DOS_HDR_LINES; strlen(Buffer) ? 1 : j++) {
 
-            (void)fgets (&Buffer[strlen (Buffer)],(int)sizeof (Buffer) - (strlen (Buffer)), f);
+            if (fgets (&Buffer[strlen (Buffer)],(int)sizeof (Buffer) - (strlen (Buffer)), f) == 0) {
+                // Ignoring fgets errors as we've done here since forever.
+                // Would be good to take another look at this later.
+            }
+ 
 
 //            if (!strlen(Buffer))
 //                j++;
  
-	        while ((ptr = strpbrk (Buffer, "\r\n")) != NULL && j < DOS_HDR_LINES) {
+            while ((ptr = strpbrk (Buffer, "\r\n")) != NULL && j < DOS_HDR_LINES) {
 
                 *ptr = '\0';
 
@@ -499,41 +507,41 @@ void draw_dos_map(Widget w,
 
                     case 0:
 //fprintf(stderr,"top_boundary: %s\n", Buffer);
-                	    top_boundary = (unsigned long) (-atof (Buffer) * 360000 + 32400000);
-                	    break;
-	      
+                        top_boundary = (unsigned long) (-atof (Buffer) * 360000 + 32400000);
+                        break;
+
                     case 1:
 //fprintf(stderr,"left_boundary: %s\n", Buffer);
-                	    left_boundary = (unsigned long) (-atof (Buffer) * 360000 + 64800000);
-                	    break;
-	      
+                        left_boundary = (unsigned long) (-atof (Buffer) * 360000 + 64800000);
+                        break;
+
                     case 2:
 //fprintf(stderr,"points_per_degree: %s\n", Buffer);
-                	    points_per_degree = (int) atof (Buffer);
-                	    break;
-	      
+                        points_per_degree = (int) atof (Buffer);
+                        break;
+
                     case 3:
 //fprintf(stderr,"bottom_boundary: %s\n", Buffer);
-                	    bottom_boundary = (unsigned long) (-atof (Buffer) * 360000 + 32400000);
-                	    bottom_boundary = bottom_boundary + bottom_boundary - top_boundary;
-                	    break;
-	      
+                        bottom_boundary = (unsigned long) (-atof (Buffer) * 360000 + 32400000);
+                        bottom_boundary = bottom_boundary + bottom_boundary - top_boundary;
+                        break;
+
                     case 4:
 //fprintf(stderr,"right_boundary: %s\n", Buffer);
-                	    right_boundary = (unsigned long) (-atof (Buffer) * 360000 + 64800000);
-                	    right_boundary = right_boundary + right_boundary - left_boundary;
-                	    break;
-	      
-                	case 5:
+                        right_boundary = (unsigned long) (-atof (Buffer) * 360000 + 64800000);
+                        right_boundary = right_boundary + right_boundary - left_boundary;
+                        break;
+
+                    case 5:
 //fprintf(stderr,"map_range: %s\n", Buffer);
-                	    map_range = (int) atof (Buffer);
-                	    break;
-	      
-                	case 7:
+//                        map_range = (int) atof (Buffer);
+                        break;
+
+                    case 7:
 //fprintf(stderr,"Map Version: %s\n", Buffer);
                         xastir_snprintf(map_version,sizeof(map_version),"%s",Buffer);
 //fprintf(stderr,"MAP VERSION: %s\n", map_version);
-                	    break;
+                        break;
                 } // end of switch
 
                 xastir_snprintf(Buffer,sizeof(Buffer),"%s",ptr);
@@ -547,27 +555,47 @@ void draw_dos_map(Widget w,
     else {
 
 // Windows-type map header portion
-	
+
         if (debug_level & 512)
             fprintf(stderr,"\nWindows map\n");
-	
-        (void)fread (map_version, 4, 1, f);
+
+        if (fread (map_version, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         map_version[4] = '\0';
       
-        (void)fread (file_name, 32, 1, f);
+        if (fread (file_name, 32, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         file_name[32] = '\0';
       
-        (void)fread (map_title, 32, 1, f);
+        if (fread (map_title, 32, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         map_title[32] = '\0';
         if (debug_level & 16)
             fprintf(stderr,"Map Title %s\n", map_title);
       
-        (void)fread (map_creator, 8, 1, f);
+        if (fread (map_creator, 8, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         map_creator[8] = '\0';
         if (debug_level & 16)
             fprintf(stderr,"Map Creator %s\n", map_creator);
       
-        (void)fread (&temp, 4, 1, f);
+        if (fread (&temp, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         creation_date = ntohl (temp);
         if (debug_level & 16)
             fprintf(stderr,"Creation Date %lX\n", creation_date);
@@ -577,16 +605,32 @@ void draw_dos_map(Widget w,
         if (debug_level & 16)
             fprintf(stderr,"year is %ld + days %ld\n", 1904l + year, (long)days);
       
-        (void)fread (&temp, 4, 1, f);
+        if (fread (&temp, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         left_boundary = ntohl (temp);
       
-        (void)fread (&temp, 4, 1, f);
+        if (fread (&temp, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         right_boundary = ntohl (temp);
       
-        (void)fread (&temp, 4, 1, f);
+        if (fread (&temp, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         top_boundary = ntohl (temp);
       
-        (void)fread (&temp, 4, 1, f);
+        if (fread (&temp, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         bottom_boundary = ntohl (temp);
       
         if (strcmp (map_version, "2.00") != 0) {
@@ -596,13 +640,30 @@ void draw_dos_map(Widget w,
             bottom_boundary *= 10;
         }
 
-        (void)fread (map_reserved1, 8, 1, f);
-        (void)fread (&temp, 4, 1, f);
+        if (fread (map_reserved1, 8, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
+        if (fread (&temp, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
         total_vector_points = (long)ntohl (temp);
-        (void)fread (&temp, 4, 1, f);
-        total_labels = (long)ntohl (temp);
-        (void)fread (map_reserved2, 140, 1, f);
 
+        if (fread (&temp, 4, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
+        total_labels = (long)ntohl (temp);
+
+        if (fread (map_reserved2, 140, 1, f) == 0) {
+            // Ignoring fread errors as we've done here since forever.
+            // Would be good to take another look at this later.
+        }
+ 
     }   // End of Windows-type map header portion
       
       
@@ -677,7 +738,7 @@ void draw_dos_map(Widget w,
     statusline(map_it,0);       // Loading/Indexing ...
 
     object_behavior = '\0';
-	
+
     if (debug_level & 16)
         fprintf(stderr,"in Boundary %s\n", map_it);
       
@@ -716,8 +777,11 @@ void draw_dos_map(Widget w,
  
         if (strncmp ("DOS ", map_type, 4) == 0) {
 
-            (void)fgets (&Buffer[strlen (Buffer)],(int)sizeof (Buffer) - (strlen (Buffer)), f);
-
+            if (fgets (&Buffer[strlen (Buffer)],(int)sizeof (Buffer) - (strlen (Buffer)), f) == 0) {
+                // Ignoring fgets errors as we've done here since forever.
+                // Would be good to take another look at this later.
+            }
+ 
             while ((ptr = strpbrk (Buffer, "\r\n")) != NULL && !dos_labels) {
                 long LatHld = 0, LongHld;
                 char *trailer;
@@ -970,30 +1034,58 @@ process:        if (strncasecmp ("Line", map_version, 4) == 0) {
 // Windows type map...
 
             last_behavior = object_behavior;
-            (void)fread (&vector_start, 1, 1, f);
-            (void)fread (&object_behavior, 1, 1, f);      // Fill Color?
 
+            if (fread (&vector_start, 1, 1, f) == 0) {
+                // Ignoring fread errors as we've done here since forever.
+                // Would be good to take another look at this later.
+            }
+ 
+            if (fread (&object_behavior, 1, 1, f) == 0) {      // Fill Color?
+                // Ignoring fread errors as we've done here since forever.
+                // Would be good to take another look at this later.
+            }
+ 
             if (strcmp (map_type, "COMP") == 0) {
                 short temp_short;
                 long LatOffset, LongOffset;
 
                 LatOffset  = (long)(top_boundary  - top_boundary  % 6000);
                 LongOffset = (long)(left_boundary - left_boundary % 6000);
-                (void)fread (&temp_short, 2, 1, f);
+
+                if (fread (&temp_short, 2, 1, f) == 0) {
+                    // Ignoring fread errors as we've done here since forever.
+                    // Would be good to take another look at this later.
+                }
+
                 x_long_cord = (ntohs (temp_short) * 10 + LongOffset);
-                (void)fread (&temp_short, 2, 1, f);
+
+                if (fread (&temp_short, 2, 1, f) == 0) {
+                    // Ignoring fread errors as we've done here since forever.
+                    // Would be good to take another look at this later.
+                }
+ 
                 y_lat_cord  = (ntohs (temp_short) * 10 + LatOffset);
             }
             else {
-                (void)fread (&temp, 4, 1, f);
+                if (fread (&temp, 4, 1, f) == 0) {
+                    // Ignoring fread errors as we've done here since forever.
+                    // Would be good to take another look at this later.
+                }
+
                 x_long_cord = ntohl (temp);
+
                 if (strcmp (map_version, "2.00") != 0)
-                x_long_cord *= 10;
+                    x_long_cord *= 10;
             
-                (void)fread (&temp, 4, 1, f);
+                if (fread (&temp, 4, 1, f) == 0) {
+                    // Ignoring fread errors as we've done here since forever.
+                    // Would be good to take another look at this later.
+                }
+ 
                 y_lat_cord = ntohl (temp);
+
                 if (strcmp (map_version, "2.00") != 0)
-                y_lat_cord *= 10;
+                    y_lat_cord *= 10;
             }
 
             if (alert_color && last_behavior & 0x80 && (int)vector_start == 0xff) {
@@ -1078,8 +1170,11 @@ process:        if (strncasecmp ("Line", map_version, 4) == 0) {
             if (strcmp (map_type, "DOS ") == 0) {   // Handle DOS-type map labels/embedded objects
                 char *trailer;
 
-                (void)fgets (&Buffer[strlen (Buffer)],(int)sizeof (Buffer) - (strlen (Buffer)), f);
-
+                if (fgets (&Buffer[strlen (Buffer)],(int)sizeof (Buffer) - (strlen (Buffer)), f) == 0) {
+                    // Ignoring fgets errors as we've done here since forever.
+                    // Would be good to take another look at this later.
+                }
+ 
                 for (; (ptr = strpbrk (Buffer, "\r\n")) != NULL;xastir_snprintf(Buffer,sizeof(Buffer),"%s",ptr)) {
 
                     *ptr = '\0';
@@ -1171,23 +1266,42 @@ process:        if (strncasecmp ("Line", map_version, 4) == 0) {
                 char label_type_1[2], label_type_2[2];
             
                 // Snag first two bytes of label
-                (void)fread (label_type_1, 1, 1, f);
-                (void)fread (label_type_2, 1, 1, f);
+                if (fread (label_type_1, 1, 1, f) == 0) {
+                    // Ignoring fread errors as we've done here since forever.
+                    // Would be good to take another look at this later.
+                }
+ 
+                if (fread (label_type_2, 1, 1, f) == 0) {
+                    // Ignoring fread errors as we've done here since forever.
+                    // Would be good to take another look at this later.
+                }
             
                 if (label_type_2[0] == '\0') {  // Found a label
               
                     // Found text label
-                    (void)fread (&temp, 4, 1, f);           /* x */
+                    if (fread (&temp, 4, 1, f) == 0) {           /* x */
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+ 
                     label_x_cord = ntohl (temp);
                     if (strcmp (map_version, "2.00") != 0)
                         label_x_cord *= 10;
               
-                    (void)fread (&temp, 4, 1, f);           /* y */
+                    if (fread (&temp, 4, 1, f) == 0) {           /* y */
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+ 
                     label_y_cord = ntohl (temp);
                     if (strcmp (map_version, "2.00") != 0)
                         label_y_cord *= 10;
               
-                    (void)fread (&temp_mag, 2, 1, f);       /* mag */
+                    if (fread (&temp_mag, 2, 1, f) == 0) {       /* mag */
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+
                     label_mag = (int)ntohs (temp_mag);
                     if (strcmp (map_version, "2.00") != 0)
                         label_mag *= 10;
@@ -1195,7 +1309,11 @@ process:        if (strncasecmp ("Line", map_version, 4) == 0) {
                     if (strcmp (map_type, "COMP") == 0) {
 
                         for (i = 0; i < 32; i++) {
-                            (void)fread (&label_text[i], 1, 1, f);
+                            if (fread (&label_text[i], 1, 1, f) == 0) {
+                                // Ignoring fread errors as we've done here since forever.
+                                // Would be good to take another look at this later.
+                            }
+ 
                             if (label_text[i] == '\0') {
                                 break;
                             }
@@ -1203,7 +1321,11 @@ process:        if (strncasecmp ("Line", map_version, 4) == 0) {
                         label_text[32] = '\0';  // Make sure we have a terminator
                     }
                     else {
-                        (void)fread (label_text, 32, 1, f);   /* text */
+                        if (fread (label_text, 32, 1, f) == 0) {   /* text */
+                            // Ignoring fread errors as we've done here since forever.
+                            // Would be good to take another look at this later.
+                        }
+ 
                         label_text[32] = '\0';  // Make sure we have a terminator
                     }
               
@@ -1302,24 +1424,47 @@ process:        if (strncasecmp ("Line", map_version, 4) == 0) {
                     //fprintf(stderr,"Found windows embedded symbol\n");
               
                     /* label is an embedded symbol */
-                    (void)fread (&temp, 4, 1, f);
+                    if (fread (&temp, 4, 1, f) == 0) {
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+
                     label_x_cord = ntohl (temp);
                     if (strcmp (map_version, "2.00") != 0)
                         label_x_cord *= 10;
           
-                    (void)fread (&temp, 4, 1, f);
+                    if (fread (&temp, 4, 1, f) == 0) {
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+
                     label_y_cord = ntohl (temp);
                     if (strcmp (map_version, "2.00") != 0)
                         label_y_cord *= 10;
               
-                    (void)fread (&temp_mag, 2, 1, f);
+                    if (fread (&temp_mag, 2, 1, f) == 0) {
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+ 
                     label_mag = (int)ntohs (temp_mag);
                     if (strcmp (map_version, "2.00") != 0)
                         label_mag *= 10;
               
-                    (void)fread (&label_symbol_del, 1, 1, f);   // Snag symbol table char
-                    (void)fread (&label_symbol_char, 1, 1, f);  // Snag symbol char
-                    (void)fread (&label_text_color, 1, 1, f);   // Snag text color (should be 1-9, others should default to black)
+                    if (fread (&label_symbol_del, 1, 1, f) == 0) { // Snag symbol table char
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+
+                    if (fread (&label_symbol_char, 1, 1, f) == 0) { // Snag symbol char
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+                    if (fread (&label_text_color, 1, 1, f) == 0) { // Snag text color (should be 1-9, others should default to black)
+                        // Ignoring fread errors as we've done here since forever.
+                        // Would be good to take another look at this later.
+                    }
+
                     if (label_text_color < '1' && label_text_color > '9')
                         label_text_color = '0'; // Default to black
               
@@ -1330,19 +1475,26 @@ process:        if (strncasecmp ("Line", map_version, 4) == 0) {
                     if (strcmp (map_type, "COMP") == 0) {
 
                         for (i = 0; i < 32; i++) {
-                            (void)fread (&label_text[i], 1, 1, f);
+                            if (fread (&label_text[i], 1, 1, f) == 0) {
+                                // Ignoring fread errors as we've done here since forever.
+                                // Would be good to take another look at this later.
+                            }
+
                             if (label_text[i] == '\0')
                                 break;
                         }
                     }
                     else {
-                        (void)fread (label_text, 29, 1, f);
+                        if (fread (label_text, 29, 1, f) == 0) {
+                            // Ignoring fread errors as we've done here since forever.
+                            // Would be good to take another look at this later.
+            }
                     }
-              
+
                     // NOTE: 0x21 is the first color for the area object or "DOS" colors
                     draw_label_text (w, x+10, y+5, strlen(label_text),colors[0x21 + label_text_color],label_text);
                     symbol(w,0,label_symbol_del,label_symbol_char,' ',pixmap,1,x-10,y-10,' ');
-              
+
                     if (debug_level & 512)
                         fprintf(stderr,"Windows map, embedded object: %c %c %c %s\n",
 
