@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -190,13 +190,16 @@ void group_build_list(char *filename) {
         }
         if (group_data_count < group_data_max) {
             group_data_list[group_data_count*10] = '\0';
-            (void)fgets(&group_data_list[group_data_count*10], 10, f);
+            if (fgets(&group_data_list[group_data_count*10], 10, f) == NULL) {
+                // Error reading file or end-of-file. Continue processing
+                // the (partial?) string we just read, in the code below.
+            }
             if ((ptr = strchr(&group_data_list[group_data_count*10], '\n')))
                 *ptr = '\0';
             else
                 while ((i = fgetc(f)) != EOF && i != '\n'); // clean-up after long group name
 
-	// check for DOS EOL markup!
+    // check for DOS EOL markup!
             if ((ptr = strchr(&group_data_list[group_data_count*10], '\r')))
                 *ptr = '\0';
             if (group_data_list[group_data_count*10])
@@ -408,7 +411,7 @@ void clear_outgoing_message(int i) {
     message_pool[i].message_line[0] = '\0';
     message_pool[i].seq[0] = '\0';
     message_pool[i].active_time=0;;
-    message_pool[i].next_time=0l;
+    message_pool[i].next_time=0L;
     message_pool[i].tries=0;
 }
 
@@ -449,7 +452,7 @@ void clear_outgoing_messages_to(char *callsign) {
             message_pool[ii].message_line[0] = '\0';
             message_pool[ii].seq[0] = '\0';
             message_pool[ii].active_time=0;;
-            message_pool[ii].next_time=0l;
+            message_pool[ii].next_time=0L;
             message_pool[ii].tries=0;
         }
     }
@@ -506,7 +509,7 @@ void change_path_outgoing_messages_to(char *callsign, char *new_path) {
 
 
 
-time_t last_check_and_transmit = (time_t)0l;
+time_t last_check_and_transmit = (time_t)0L;
 
 
 // Kick the interval timer back to 7 and tries back to 1 for
@@ -525,14 +528,14 @@ void kick_outgoing_timer(char *callsign) {
 
         // If it matches the callsign we're talking to
         if (strcasecmp(message_pool[ii].to_call_sign,callsign) == 0) {
-            message_pool[ii].next_time = (time_t)7l;
+            message_pool[ii].next_time = (time_t)7L;
             message_pool[ii].tries = 0;
-            message_pool[ii].active_time = (time_t)0l;
+            message_pool[ii].active_time = (time_t)0L;
         }
     }
 
     // Cause the transmit routine to get called again
-    last_check_and_transmit = (time_t)0l;
+    last_check_and_transmit = (time_t)0L;
 }
 
 
@@ -714,7 +717,7 @@ void output_message(char *from, char *to, char *message, char *path) {
 
                 // Increment the message sequence ID variable
                 if (bump_message_counter(message_counter)) 
-		   fprintf(stderr, "!WARNING!: Wrap around Message Counter");
+           fprintf(stderr, "!WARNING!: Wrap around Message Counter");
 
 
 // Note that Xastir's messaging can lock up if we do a rollover and
@@ -766,7 +769,7 @@ void output_message(char *from, char *to, char *message, char *path) {
                     message_counter[1]);
 
                 message_pool[i].active_time=0;
-                message_pool[i].next_time = (time_t)7l;
+                message_pool[i].next_time = (time_t)7L;
 
                 if (strcmp(from,"***")!= 0)
                     message_pool[i].tries = 0;
@@ -997,7 +1000,7 @@ void transmit_message_data_delayed(char *to, char *message,
             // We have matches on call_sign and message.  Check the
             // time next.
             //
-            if (abs(when - ptr->active_time) < 30) {
+            if (labs(when - ptr->active_time) < 30) {
                 //
                 // We're within 30 seconds of an identical ack.
                 // Drop this new one (don't add it).
@@ -1281,8 +1284,8 @@ fprintf(stderr,
                     message_pool[i].next_time = message_pool[i].next_time * 2;
 
                     // Limit the max interval to 10 minutes
-                    if (message_pool[i].next_time > (time_t)600l)
-                        message_pool[i].next_time = (time_t)600l;
+                    if (message_pool[i].next_time > (time_t)600L)
+                        message_pool[i].next_time = (time_t)600L;
 
                     message_pool[i].tries++;
 
