@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -413,7 +413,7 @@ void Send_message_change_path_default(Widget widget, XtPointer clientData, XtPoi
 //
 void Send_message_change_path( Widget widget, XtPointer clientData, XtPointer callData) {
     int ii;
-    Atom delw;
+    //Atom delw;
     Widget pane, form, current_path_label, reverse_path_label,
         reverse_path, button_default, button_direct, button_apply,
         button_cancel;
@@ -740,7 +740,8 @@ XtSetSensitive(button_nogate, FALSE);
  
     pos_dialog(change_path_dialog);
 
-    delw = XmInternAtom(XtDisplay(change_path_dialog),"WM_DELETE_WINDOW", FALSE);
+    //delw
+    (void)XmInternAtom(XtDisplay(change_path_dialog),"WM_DELETE_WINDOW", FALSE);
 //    XmAddWMProtocolCallback(change_path_dialog, delw, Send_message_destroy_shell, (XtPointer)mw[ii].win);
 
     XtManageChild(form);
@@ -959,7 +960,7 @@ void Send_message_now( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/
     char temp_line2[23] = "";
     char temp_line3[23] = "";
     char temp_line4[10] = "";
-#endif	// NO_DYNAMIC_WIDGETS
+#endif    // NO_DYNAMIC_WIDGETS
 
     char path[200];
     int ii, jj;
