@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -494,36 +494,45 @@ static void* findu_transfer_thread(void *arg) {
         "%s -i -e \"s/<br>/   /\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
-//fprintf(stderr,"%s\n", sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
 
 // Greater-than symbol '>'
     sprintf(sys_cmd,
         "%s -i -e \"s/&gt;/>/\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
 
 // Less-than symbol '<'
     sprintf(sys_cmd,
         "%s -i -e \"s/&lt;/</\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
 
 // Ampersand '&' (A difficult character to escape from the shell!)
     sprintf(sys_cmd,
         "%s -i -e \"s/&amp;/\\&/\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
 
 // Double-quote symbol '"'
     sprintf(sys_cmd,
         "%s -i -e \"s/&quot;/""/\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
 
 // Remove whitespace at the start of a line
 // sed 's/^[ \t]*//'
@@ -531,21 +540,27 @@ static void* findu_transfer_thread(void *arg) {
         "%s -i -e \"s/^[ \t]*//\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    } 
 
 // Remove any lines that start with '<'
     sprintf(sys_cmd,
         "%s -i -e \"s/^<.*$//\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
 
 // Remove any lines that start with '"http'
     sprintf(sys_cmd,
         "%s -i -e \"/^\\\"http.*$/d\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
 
 // Remove any blank lines from the file
 // sed '/^$/d'
@@ -553,13 +568,16 @@ static void* findu_transfer_thread(void *arg) {
         "%s -i -e \"/^$/d\" %s",
         SED_PATH,
         log_filename);
-    system(sys_cmd);
+    if (system(sys_cmd)) {
+        fprintf(stderr,"Couldn't execute command: %s\n", sys_cmd);
+    }
+ 
 #endif  // HAVE_SED
 
 /*
 #ifdef HAVE_HTML2TEXT
     // Create temp filename
-    snprintf(log_filename_tmp, sizeof(log_filename_tmp), "%s%s",
+    xastir_snprintf(log_filename_tmp, sizeof(log_filename_tmp), "%s%s",
         log_filename,
         ".tmp");
     // Create html2text command
@@ -569,7 +587,7 @@ static void* findu_transfer_thread(void *arg) {
         log_filename_tmp,
         log_filename);
     // Convert the newly-downloaded file from html to text format
-    system(sys_cmd);
+    (void)system(sys_cmd);
     // Rename the file so that we can keep the static char* name
     // pointing to it, needed for the read_file_ptr code in the main
     // thread.
@@ -579,7 +597,7 @@ static void* findu_transfer_thread(void *arg) {
         MV_PATH,
         log_filename_tmp,
         log_filename);
-    system(sys_cmd);
+    (void)system(sys_cmd);
 #endif  // HAVE_MV
 #endif  // HAVE_HTML2TEXT
 */
