@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -117,8 +117,8 @@ end_critical_section(&wx_detailed_alert_shell_lock, "wx_gui.c:wx_detailed_alert_
 void wx_alert_finger_output( Widget widget, char *handle) {
     static Widget pane, my_form, mess, button_cancel,wx_detailed_alert_list;
     Atom delw;
-    Arg al[50];                     // Arg List
-    register unsigned int ac = 0;   // Arg Count
+    Arg al[50];             // Arg List
+    unsigned int ac = 0;    // Arg Count
     char temp[1024];
     XmString item;
     FILE *fd;
@@ -401,7 +401,7 @@ void wx_alert_double_click_action( Widget widget, XtPointer clientData, XtPointe
         "%s",
         choice);
 
-    XtFree(choice);	// Release as soon as we're done!
+    XtFree(choice);    // Release as soon as we're done!
 
     handle[13] = '\0';  // Terminate the string
     // Remove spaces
@@ -493,17 +493,17 @@ begin_critical_section(&wx_alert_shell_lock, "wx_gui.c:wx_alert_update_list" );
         // Get the previous alert count from the alert list window
         XtVaGetValues(wx_alert_list, XmNitemCount, &max_item_count, NULL);
 
-	if ((nn = alert_list_count()) > alert_list_limit) {
-	    alert_entry **tmp = realloc(alert_list, nn * sizeof(alert_entry *));
-	    if (tmp) {
-		alert_list = tmp;
-		alert_list_limit = nn;
-	    } else {
-		fprintf(stderr, "wx_gui: Alert list allocation error\n");
-		exit(1);
-	    }
+    if ((nn = alert_list_count()) > alert_list_limit) {
+        alert_entry **tmp = realloc(alert_list, nn * sizeof(alert_entry *));
+        if (tmp) {
+        alert_list = tmp;
+        alert_list_limit = nn;
+        } else {
+        fprintf(stderr, "wx_gui: Alert list allocation error\n");
+        exit(1);
+        }
 
-	}
+    }
         // Iterate through the alert hash.  Create a string for each
         // non-expired/non-blank entry.
         iterator = create_wx_alert_iterator();
@@ -515,13 +515,13 @@ begin_critical_section(&wx_alert_shell_lock, "wx_gui.c:wx_alert_update_list" );
             // probably don't need this anymore.
             //
 //            if (alert->title[0] == '\0') {    // It's empty
-//		fprintf(stderr, "wx_gui:alert->title NULL\n");
+//        fprintf(stderr, "wx_gui:alert->title NULL\n");
 //                break;
 //            }
-	    alert_list[nn++] = alert;
-	}
-	qsort(alert_list, nn, sizeof(alert_entry *), alert_comp);
-	for (ii = 0; ii < nn; 
+        alert_list[nn++] = alert;
+    }
+    qsort(alert_list, nn, sizeof(alert_entry *), alert_comp);
+    for (ii = 0; ii < nn; 
 ) {
             alert = alert_list[ii];
             // AFGNPW      NWS-WARN    Until: 191500z   AK_Z213   WIND               P7IAA
@@ -565,7 +565,7 @@ begin_critical_section(&wx_alert_shell_lock, "wx_gui.c:wx_alert_update_list" );
             if (max_item_count < ii) {
                 XmListAddItemUnselected(wx_alert_list, item, 0);
             } else {
-		// Replace it in the window.  Note: This might re-order the list each time.
+        // Replace it in the window.  Note: This might re-order the list each time.
                 XmListReplaceItemsPos(wx_alert_list, &item, 1, ii);
             }
 
@@ -595,7 +595,7 @@ void Display_Wx_Alert( /*@unused@*/ Widget wdgt, /*@unused@*/ XtPointer clientDa
     static Widget pane, my_form, mess, button_cancel;
     Atom delw;
     Arg al[50];                    /* Arg List */
-    register unsigned int ac = 0;           /* Arg Count */
+    unsigned int ac = 0;           /* Arg Count */
 
     if(!wx_alert_shell) {
 
@@ -794,14 +794,12 @@ void WX_station_change_data(Widget widget, XtPointer clientData, XtPointer callD
 //
 void WX_station( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer callData) {
     static Widget  pane, my_form, form1, button_close, frame, 
-            WX_type, temp, wind_cse, wind_deg, wind_spd, wind_gst, 
+            WX_type, temp, wind_cse, wind_spd, wind_gst, 
             my_rain, to_rain, rain_h, my_rain_24, baro,
-            humidity, humidity_n,
             dew_point,
             high_wind, wind_chill,
             heat_index, three_hour_baro,
-            hi_temp, low_temp,
-            sts;
+            hi_temp;
 
     Atom delw;
 
@@ -871,7 +869,8 @@ XmNtraversalOn, FALSE,
                                     XmNbackground, colors[0xff], 
                                     NULL);
 
-        sts  = XtVaCreateManagedWidget(langcode("WXPUPSI002"),xmLabelWidgetClass,frame,
+        // sts
+        (void)XtVaCreateManagedWidget(langcode("WXPUPSI002"),xmLabelWidgetClass,frame,
 XmNtraversalOn, FALSE,
                                     XmNchildType, XmFRAME_TITLE_CHILD,
                                     XmNbackground, colors[0xff], 
@@ -919,7 +918,8 @@ XmNtraversalOn, FALSE,
                                       XmNfontList, fontlist1,
                                       NULL);
 
-        wind_deg = XtVaCreateManagedWidget(langcode("UNIOP00024"),xmLabelWidgetClass, form1,
+        // wind_deg
+        (void)XtVaCreateManagedWidget(langcode("UNIOP00024"),xmLabelWidgetClass, form1,
                                       XmNtopAttachment, XmATTACH_FORM,
                                       XmNtopOffset, 12,
                                       XmNbottomAttachment, XmATTACH_NONE,
@@ -1277,7 +1277,8 @@ XmNtraversalOn, FALSE,
                                       XmNfontList, fontlist1,
                                       NULL);
 
-        humidity = XtVaCreateManagedWidget(langcode("WXPUPSI010"),xmLabelWidgetClass, form1,
+        // humidity
+        (void)XtVaCreateManagedWidget(langcode("WXPUPSI010"),xmLabelWidgetClass, form1,
                                       XmNtopAttachment, XmATTACH_WIDGET,
                                       XmNtopWidget, my_rain_24,
                                       XmNtopOffset, 11,
@@ -1308,7 +1309,8 @@ XmNtraversalOn, FALSE,
                                       XmNfontList, fontlist1,
                                       NULL);
 
-        humidity_n = XtVaCreateManagedWidget(langcode("UNIOP00026"),xmLabelWidgetClass, form1,
+        // humidity_n
+        (void)XtVaCreateManagedWidget(langcode("UNIOP00026"),xmLabelWidgetClass, form1,
                                       XmNtopAttachment, XmATTACH_WIDGET,
                                       XmNtopWidget, my_rain_24, 
                                       XmNtopOffset, 12,
@@ -1642,7 +1644,8 @@ XmNtraversalOn, FALSE,
                                       XmNfontList, fontlist1,
                                       NULL);
 
-        low_temp = XtVaCreateManagedWidget(langcode("WXPUPSI024"),xmLabelWidgetClass, form1,
+        // low_temp
+        (void)XtVaCreateManagedWidget(langcode("WXPUPSI024"),xmLabelWidgetClass, form1,
                                       XmNtopAttachment, XmATTACH_WIDGET,
                                       XmNtopWidget, hi_temp,
                                       XmNtopOffset, 11,
